ingredients package
===================

Submodules
----------

ingredients.cli module
----------------------

.. automodule:: ingredients.cli
    :members:
    :undoc-members:
    :show-inheritance:

ingredients.ingredients module
------------------------------

.. automodule:: ingredients.ingredients
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ingredients
    :members:
    :undoc-members:
    :show-inheritance:
